﻿// (c) 2013 Cesys GmbH
// Author: Thomas Hoppe
using System;
using System.Collections.Generic;
using System.Text;

namespace CeboMsrNet
{
    /// <summary>
    /// Offers functionality for counter periphery. Instances can be retrieved from
    /// Counters of the respective Device instance.
    /// </summary>
    public sealed class Counter : IInput
    {
        /// <summary>
        /// The possible counter configuration values.
        /// </summary>
        public enum CounterConfig : uint
        {
            RisingEdge = SystemConnector.CeboMsrCounterConfigRisingEdge,
            FallingEdge = SystemConnector.CeboMsrCounterConfigFallingEdge,
            Alternating = SystemConnector.CeboMsrCounterConfigAlternating
        }

        private Device _device;
        private uint _interfaceId;
        private int _index;
        private string _name;

        internal uint InterfaceId { get { return _interfaceId; } }
        internal int Index { get { return _index; } }

        internal Counter(Device device, uint interfaceId, int index)
        {
            _device = device;
            _interfaceId = interfaceId;
            _index = index;
            _name = SystemConnector.GetPeripheralName(device.Handle, interfaceId);
        }

        /// <summary>
        /// Reset counter to 0.
        /// </summary>
        public void Reset()
        {
            SystemConnector.ResetCounter(_device.Handle, _interfaceId);
        }

        /// <summary>
        /// Define or retrieve the counters enabled state.
        /// </summary>
        public bool Enabled
        {
            get { return SystemConnector.GetCounterEnable(_device.Handle, _interfaceId); }
            set { SystemConnector.SetCounterEnable(_device.Handle, _interfaceId, value); }
        }

        /// <summary>
        /// Define and request behavior of the counter.
        /// </summary>
        public CounterConfig Config
        {
            get { return (CounterConfig)SystemConnector.GetCounterConfig(_device.Handle, _interfaceId); }
            set { SystemConnector.SetCounterConfig(_device.Handle, _interfaceId, (uint)value); }
        }

        /// <summary>
        /// Current counter value.
        /// </summary>
        public long Value
        {
            get { return SystemConnector.ReadCounter(_device.Handle, _interfaceId); }
        }

        /// <summary>
        /// Name of the component.
        /// </summary>
        public string Name { get { return _name; } }

        public override string ToString()
        {
            return "Counter" + _index;
        }
    }
}
