package com.cesys.cebo.cebomsr;

import java.io.IOException;

/**
 * Offers functionality of for LED's. Instances can be retrieved using getLeds()
 * of the respective {@link Device} instance.
 *
 * @author Thomas Hoppe
 */
public final class Led {
	private final Device _device;
	private final int _interfaceId;
	private final String _name;

	int getInterfaceId() {
		return _interfaceId;
	}

	Led(Device device, int interfaceId, int index) throws IOException {
		_device = device;
		_interfaceId = interfaceId;
		byte[] tmp = new byte[SystemConnector.MaxIdentLength];
		SystemConnector.checkError(SystemConnector.CeboMsrGetPeripheralName(device.getHandle(), interfaceId, tmp));
		_name = Utils.convertByteArrayToString(tmp);
	}

	/**
	 * Set state of the on-board led.
	 * @param enable State to switch the indicator to.
	 */
	public void setEnabled(boolean enable) throws IOException {
		SystemConnector.checkError(SystemConnector.CeboMsrSetLed(_device.getHandle(), getInterfaceId(), enable ? 1 : 0));
	}

	/**
	 * Returns name of the component.
	 */
	public String getName() {
		return _name;
	}
}
